<!-- ------------------- generated docs start ------------------- -->
# twitch-dl chat

Render chat in various formats (experimental)

### USAGE

```
twitch-dl chat [OPTIONS] COMMAND [ARGS]...
```

### COMMANDS

| Command | Description |
| ------- | ----------- |
| [video](chat_video.md) | Render twitch chat as video |
| [json](chat_json.md) | Render twitch chat as json |
| [ytt](chat_ytt.md) | Render twitch chat as youtube subtitles |

<!-- ------------------- generated docs end ------------------- -->

<h2>Experimental command</h2>

Chat commands are still experimental and the CLI may change.